# MOFUN

[![MOFUN Refactor Branch Test Status](https://github.com/paulboone/mofun/actions/workflows/python-app.yml/badge.svg?branch=refactor2)](https://github.com/paulboone/mofun/actions/workflows/python-app.yml)

See [Documentation](https://paulboone.github.io/mofun/)
